@@ -23,10 +23,14 @@ from .schema.api_schema import \
     ConceptMutationInput, ConceptUpdateInput, ConceptPropertyUpdateInput, ConceptPropertyCreateInput, \
     ConceptLinkPropertyInput, ConceptLinkCreationMutationInput, ComponentValueInput, CompositeConcept, \
     CompositeConceptWidgetRowPagination, DocumentLinkFilterSetting, ConceptFact, \
-    ConceptLinkPropertyTypeCreationInput, ConceptPropertyTypeCreationInput, State
+    ConceptLinkPropertyTypeCreationInput, ConceptPropertyTypeCreationInput, State, \
+    CompositePropertyValueTemplate, CompositePropertyValueType, CompositeValue, DateTimeValueInput, \
+    LinkValueInput, DoubleValueInput, StringLocaleValueInput, CompositePropertyTypeFilterSettings, \
+    ConceptLinkPropertyTypeUpdateInput
 from .schema.crawlers_api_schema import Query as CrQuery
 from .schema.crawlers_api_schema import Crawler, CrawlerPagination
 from .schema import utils_api_schema as uas
+from .schema import tcontroller_api_schema as tc
 from sgqlc.operation import Operation, Fragment
 
 
@@ -58,7 +62,8 @@ class TalismanAPIAdapter:
 
         self.document_fields_truncated = ('id', 'external_url')
         self.document_fields = (
-            'id', 'title', 'external_url', 'publication_author', 'publication_date', 'internal_url', 'markers'
+            'id', 'title', 'external_url', 'publication_author', 'publication_date', 'internal_url', 'markers',
+            'system_registration_date', 'system_update_date', 'access_level', 'trust_level'
         )
         self.document_fields_extended = (
             'id', 'title', 'publication_author', 'publication_date', 'external_url',
@@ -69,8 +74,10 @@ class TalismanAPIAdapter:
         self.document_text_fields = ('node_id', 'text')
         self.document_text_metadata_fields = ('paragraph_type',)
 
-        self.document_platform_fields = ('id',)
-        self.document_account_fields = ('id',)
+        self.document_platform_fields = ('id', 'name')
+        self.document_account_fields = ('id', 'name')
+
+        self.user_fields = ('id', 'name')
 
         self.concept_fields = (
             'id', 'name', 'notes', 'metric', 'markers', 'system_registration_date', 'system_update_date'
@@ -97,6 +104,11 @@ class TalismanAPIAdapter:
         self.date_time_value_date_fields = ('year', 'month', 'day')
         self.date_time_value_time_fields = ('hour', 'minute', 'second')
 
+        self.pipeline_config_fields = ('id', 'description')
+
+        self.pipeline_topic_fields = ('topic', 'description', 'stopped', 'metrics', 'pipeline')
+        self.pipeline_metrics_fields = ('duplicate', 'failed', 'messages', 'ok')
+
         self.tdm_builder = tdm_builder
 
         if kb_iterator_config:
@@ -134,12 +146,12 @@ class TalismanAPIAdapter:
         for f in self.cpvt_fields_truncated if truncated else self.cpvt_fields:
             conpvt_frag.__getattr__(f)()
 
-        # TODO: add composite types
-        # compvt_frag = Fragment(CompositePropertyValueTemplate, 'CompositePropertyValueTemplate')
-        # compvt_frag.__fields__('id', 'name')
-        # compvt_frag.component_value_types()
+        compvt_frag = Fragment(CompositePropertyValueTemplate, 'CompositePropertyValueTemplate')
+        compvt_frag.__fields__('id', 'name')
+        compvt_frag.component_value_types()
 
         graphql_value.__fragment__(conpvt_frag)
+        graphql_value.__fragment__(compvt_frag)
 
     def _configure_output_value_fields(self, graphql_value):
         dtv_frag = Fragment(DateTimeValue, 'DateTimeFull')
@@ -166,12 +178,23 @@ class TalismanAPIAdapter:
         iv_frag = Fragment(IntValue, 'IntFull')
         iv_frag.value(__alias__='number')
 
+        cv_frag = Fragment(CompositeValue, 'CompFull')
+        cv_frag.list_value().id()
+        cv_frag.list_value().property_value_type()
+        cv_frag.list_value().value().__fragment__(slv_frag)
+        cv_frag.list_value().value().__fragment__(sv_frag)
+        cv_frag.list_value().value().__fragment__(lv_frag)
+        cv_frag.list_value().value().__fragment__(dv_frag)
+        cv_frag.list_value().value().__fragment__(iv_frag)
+        cv_frag.list_value().value().__fragment__(dtv_frag)
+
         graphql_value.__fragment__(slv_frag)
         graphql_value.__fragment__(sv_frag)
         graphql_value.__fragment__(lv_frag)
         graphql_value.__fragment__(dv_frag)
         graphql_value.__fragment__(iv_frag)
         graphql_value.__fragment__(dtv_frag)
+        graphql_value.__fragment__(cv_frag)
         # graphql_value.__fragment__(dtiv_frag)
 
     def _configure_output_concept_fields(
@@ -257,6 +280,38 @@ class TalismanAPIAdapter:
 
         return res.add_concept
 
+    def _get_components_mapping(
+        self, component_values: Dict[str, str],
+        component_value_types: List[CompositePropertyValueType]
+    ) -> Dict[str, CompositePropertyValueType]:
+        components_type_mapping = {}
+        for component_value in component_values:
+            for component_value_type in component_value_types:
+                if component_value_type.name != component_values[component_value]:
+                    continue
+                components_type_mapping[component_value] = component_value_type
+        return components_type_mapping
+
+    def _get_value_input(
+        self, values: dict, components_type_mapping: Dict[str, CompositePropertyValueType]
+    ) -> List[ComponentValueInput]:
+        value_input = []
+        for field in values:
+            if field not in components_type_mapping:
+                continue
+            value_id = components_type_mapping[field].id
+            value_input.append(ComponentValueInput(
+                id=value_id,
+                value=get_map_helper(
+                    components_type_mapping[field].value_type.value_type).get_value_input(values[field])
+            ))
+        return value_input
+
+    def _configure_pipeline_topic_fields(self, kafka_topic: tc.KafkaTopic):
+        kafka_topic.__fields__(*self.pipeline_topic_fields)
+        kafka_topic.metrics().__fields__(*self.pipeline_metrics_fields)
+        kafka_topic.pipeline().pipeline_config().__fields__(*self.pipeline_config_fields)
+
     def get_all_documents(
         self, grouping: DocumentGrouping = 'none', filter_settings: DocumentFilterSettings = None,
         direction: SortDirection = 'descending', sort_field: DocumentSorting = 'score',
@@ -387,9 +442,15 @@ class TalismanAPIAdapter:
             id=document_id
         )
         d.__fields__(*self.document_fields)
+        d.last_updater().__fields__(*self.user_fields)
+        d.metadata().platform().__fields__(*self.document_platform_fields)
+        d.metadata().account().__fields__(*self.document_account_fields)
+        d.creator().__fields__(*self.user_fields)
         dt = d.text(show_hidden=True)
         dt.__fields__(*self.document_text_fields)
         dt.metadata().__fields__(*self.document_text_metadata_fields)
+        dt.metadata().text_translations().text()
+        dt.metadata().text_translations().language().id()
         cd = d.list_child()
         cd.__fields__(*self.document_fields)
         cdt = cd.text(show_hidden=True)
@@ -420,13 +481,18 @@ class TalismanAPIAdapter:
         res = op + res
         return res.pagination_concept_link.total
 
-    def get_concept(self, concept_id: str, with_aliases: bool = False) -> Concept:
+    def get_concept(
+        self, concept_id: str, with_aliases: bool = False,
+        with_properties: bool = True, with_links: bool = True,
+        with_link_properties: bool = True, with_facts: bool = False
+    ) -> Concept:
         op = Operation(Query)
         c: Concept = op.concept(
             id=concept_id
         )
         self._configure_output_concept_fields(
-            c, with_aliases=with_aliases, with_link_properties=True, with_links=True, with_properties=True
+            c, with_aliases=with_aliases, with_properties=with_properties,
+            with_links=with_links, with_link_properties=with_link_properties, with_facts=with_facts
         )
         res = self._gql_client.execute(op)
         res = op + res
@@ -975,6 +1041,68 @@ class TalismanAPIAdapter:
 
         return res.update_concept_property
 
+    def update_concept_composite_property(self, cp: ConceptProperty) -> ConceptProperty:
+        value_input = []
+        for value in cp.value.list_value:
+            if type(value.value) is StringValue:
+                value_input.append(ComponentValueInput(
+                    id=value.id,
+                    value=ValueInput(
+                        string_value_input=StringValueInput(value=value.value.value)
+                    ))
+                )
+            elif type(value.value) is IntValue:
+                value_input.append(ComponentValueInput(
+                    id=value.id,
+                    value=ValueInput(
+                        int_value_input=IntValueInput(value=value.value.number)
+                    ))
+                )
+            elif type(value.value) is DateTimeValue:
+                value_input.append(ComponentValueInput(
+                    id=value.id,
+                    value=ValueInput(
+                        date_time_value_input=DateTimeValueInput(date=value.value.date, time=value.value.time)
+                    ))
+                )
+            elif type(value.value) is StringLocaleValue:
+                value_input.append(ComponentValueInput(
+                    id=value.id,
+                    value=ValueInput(
+                        string_locale_value_input=StringLocaleValueInput(
+                            value=value.value.value,
+                            locale=value.value.locale
+                        )
+                    ))
+                )
+            elif type(value.value) is LinkValue:
+                value_input.append(ComponentValueInput(
+                    id=value.id,
+                    value=ValueInput(
+                        link_value_input=LinkValueInput(link=value.value.link)
+                    ))
+                )
+            elif type(value.value) is DoubleValue:
+                value_input.append(ComponentValueInput(
+                    id=value.id,
+                    value=ValueInput(
+                        double_value_input=DoubleValueInput(double=value.value.double)
+                    ))
+                )
+        op = Operation(Mutation)
+        ucp: ConceptProperty = op.update_concept_property(
+            form=ConceptPropertyUpdateInput(
+                property_id=cp.id,
+                is_main=cp.is_main,
+                value_input=value_input
+            )
+        )
+        ucp.__fields__('id')
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.update_concept_property
+
     def delete_concept_property(self, cp_id: str) -> bool:
         op = Operation(Mutation)
         dcp = op.delete_concept_property(
@@ -1069,12 +1197,16 @@ class TalismanAPIAdapter:
                 return prop_type
         return None
 
-    def get_concept_property_value_types_by_name(self, prop_value_type_name: str) -> Sequence[ConceptPropertyValueType]:
+    def get_concept_property_value_types_by_name(
+        self, prop_value_type_name: str, limit: int = 20, offset: int = 0
+    ) -> Sequence[ConceptPropertyValueType]:
         op = Operation(Query)
         cpvtp: ConceptPropertyValueTypePagination = op.pagination_concept_property_value_type(
             filter_settings=ConceptPropertyValueTypeFilterSettings(
                 name=prop_value_type_name
-            )
+            ),
+            limit=limit,
+            offset=offset
         )
         cpvtp.list_concept_property_value_type().__fields__(*self.cpvt_fields)
         res = self._gql_client.execute(op)
@@ -1119,8 +1251,26 @@ class TalismanAPIAdapter:
         res = op + res
         return res.pagination_concept_link_property_type.list_concept_property_type
 
+    def get_composite_link_properties_types_by_name(
+        self, link_type_id: str, prop_name: str
+    ) -> Sequence[ConceptPropertyType]:
+        op = Operation(Query)
+        cptp: ConceptPropertyTypePagination = op.pagination_composite_link_property_type(
+            filter_settings=CompositePropertyTypeFilterSettings(
+                name=prop_name,
+                link_type_id=link_type_id
+            )
+        )
+        lcpt = cptp.list_concept_property_type()
+        lcpt.__fields__(*self.concept_property_type_fields)
+        self._configure_property_value_type_fields(lcpt.value_type, True)
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.pagination_composite_link_property_type.list_concept_property_type
+
     def get_link_property_type(
-        self, link_type_code: str, link_type: ConceptLinkType, property_type_code: str
+        self, link_type_code: str, link_type: ConceptLinkType,
+        property_type_code: str, is_composite: Optional[bool] = False
     ) -> Optional[ConceptPropertyType]:
         # link_type = self.get_link_type(link_type_code)
         # if not link_type:
@@ -1138,8 +1288,12 @@ class TalismanAPIAdapter:
                 break
         if not link_type_mapping:
             raise Exception('Cannot get link mapping object')
-        prop_type_name = link_type_mapping['properties'][property_type_code]
-        types = self.get_link_properties_types_by_name(link_type.id, prop_type_name)
+        if is_composite:
+            prop_type_name = link_type_mapping['composite_properties'][property_type_code]['name']
+            types = self.get_composite_link_properties_types_by_name(link_type.id, prop_type_name)
+        else:
+            prop_type_name = link_type_mapping['properties'][property_type_code]
+            types = self.get_link_properties_types_by_name(link_type.id, prop_type_name)
         for prop_type in types:
             if prop_type.name == prop_type_name:
                 self._cache[f'link_property_type_{link_type_code}_{property_type_code}'] = prop_type
@@ -1182,11 +1336,15 @@ class TalismanAPIAdapter:
         property_type: ConceptPropertyType = self.get_concept_property_type(concept_type_code, property_type_code)
         if not property_type:
             raise Exception('Cannot add property: no property type id')
-        prop = self.add_property_by_id(
-            concept_id, property_type.id, value, is_main, property_type.value_type.value_type,
-            perform_synchronously=perform_synchronously
-        )
-
+        if type(property_type.value_type) is CompositePropertyValueTemplate:
+            prop = self.add_composite_property_by_id(
+                concept_id, property_type.id, value, is_main, property_type.value_type.component_value_types,
+                concept_type_code, property_type_code, perform_synchronously
+            )
+        else:
+            prop = self.add_property_by_id(
+                concept_id, property_type.id, value, is_main, property_type.value_type.value_type, perform_synchronously
+            )
         if self.tdm_builder is not None:
             self.tdm_builder.add_concept_property_fact(prop, self.get_concept(concept_id), value, property_type)
 
@@ -1229,7 +1387,7 @@ class TalismanAPIAdapter:
 
         aclpt = op.add_concept_link_property_type(
             form=ConceptLinkPropertyTypeCreationInput(
-                link_type_id = link_type_id,
+                link_type_id=link_type_id,
                 name=name,
                 value_type_id=value_type_id,
             )
@@ -1240,6 +1398,25 @@ class TalismanAPIAdapter:
 
         return res.add_concept_link_property_type
 
+    def update_concept_link_property_type(
+        self, link_property_type_id: str, name: str, value_type_id: str
+    ) -> ConceptPropertyType:
+
+        op = Operation(Mutation)
+
+        acpt = op.update_concept_link_property_type(
+            form=ConceptLinkPropertyTypeUpdateInput(
+                id=link_property_type_id,
+                name=name,
+                value_type_id=value_type_id,
+            )
+        )
+        acpt.__fields__(*self.concept_property_type_fields)
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.update_concept_link_property_type
+
     def delete_concept_link_property_type(
         self, property_type_id: str
     ) -> State:
@@ -1262,7 +1439,7 @@ class TalismanAPIAdapter:
 
         acpt = op.add_concept_property_type(
             form=ConceptPropertyTypeCreationInput(
-                concept_type_id = concept_type_id,
+                concept_type_id=concept_type_id,
                 name=name,
                 value_type_id=value_type_id,
             )
@@ -1287,18 +1464,88 @@ class TalismanAPIAdapter:
 
         return res.delete_concept_property_type
 
+    def add_link_composite_property_by_id(
+        self, link_id: str, property_type_id: str, values: dict,
+        component_value_types: List[CompositePropertyValueType],
+        link_composite_property_code: str, link_code: str, is_main: bool, perform_synchronously: Optional[bool] = None
+    ) -> ConceptProperty:
+        for relation in self._types['relations_types_mapping']:
+            if relation['old_relation_type'] != link_code:
+                continue
+            component_values = relation['composite_properties'][link_composite_property_code]['component_values']
+            components_type_mapping = self._get_components_mapping(component_values, component_value_types)
+            break
+        value_input = self._get_value_input(values, components_type_mapping)
+        perform_synchronously = self.get_perform_synchronously_value(perform_synchronously)
+        op = Operation(Mutation)
+
+        aclp = op.add_concept_link_property(
+            performance_control=PerformSynchronously(
+                perform_synchronously=perform_synchronously
+            ),
+            form=ConceptLinkPropertyInput(
+                property_type_id=property_type_id,
+                link_id=link_id,
+                is_main=is_main,
+                value_input=value_input
+            )
+        )
+        aclp.__fields__('id')
+        aclp.property_type().__fields__(*self.concept_property_type_fields)
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.add_concept_link_property
+
+    def add_composite_property_by_id(
+        self, id: str, type_id: str, values: dict, is_main: bool,
+        component_value_types: List[CompositePropertyValueType], concept_type_code: str, property_type_code: str,
+        perform_synchronously: Optional[bool] = None
+    ) -> ConceptProperty:
+        concept_composite_properties = self._types['concepts_types_mapping'][concept_type_code]['composite_properties']
+        concept_component_values = concept_composite_properties[property_type_code]['component_values']
+        components_type_mapping = self._get_components_mapping(concept_component_values, component_value_types)
+        value_input = self._get_value_input(values, components_type_mapping)
+        perform_synchronously = self.get_perform_synchronously_value(perform_synchronously)
+        op = Operation(Mutation)
+        acp = op.add_concept_property(
+            performance_control=PerformSynchronously(
+                perform_synchronously=perform_synchronously
+            ),
+            form=ConceptPropertyCreateInput(
+                concept_id=id,
+                property_type_id=type_id,
+                is_main=is_main,
+                value_input=value_input
+            )
+        )
+        acp.__fields__('id')
+        acp.property_type().__fields__(*self.concept_property_type_fields)
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.add_concept_property
+
     def add_link_property(
         self, link_id: str, link_type_code: str, link_type: ConceptLinkType, property_type_code: str, value: Any,
-        is_main: bool = False, perform_synchronously: Optional[bool] = None
+        is_composite: Optional[bool] = False, is_main: bool = False, perform_synchronously: Optional[bool] = None
     ) -> ConceptProperty:
 
-        property_type: ConceptPropertyType = self.get_link_property_type(link_type_code, link_type, property_type_code)
+        property_type: ConceptPropertyType = self.get_link_property_type(
+            link_type_code, link_type, property_type_code, is_composite
+        )
         if not property_type:
             raise Exception('Cannot add property: no property type id')
-        link_property = self.add_link_property_by_id(
-            link_id, property_type.id, value, is_main,
-            property_type.value_type.value_type, perform_synchronously=perform_synchronously
-        )
+        if is_composite:
+            link_property = self.add_link_composite_property_by_id(
+                link_id, property_type.id, value, property_type.value_type.component_value_types,
+                property_type_code, link_type_code, is_main, perform_synchronously
+            )
+        else:
+            link_property = self.add_link_property_by_id(
+                link_id, property_type.id, value, is_main,
+                property_type.value_type.value_type, perform_synchronously=perform_synchronously
+            )
 
         if self.tdm_builder is not None:
             self.tdm_builder.add_link_property_fact(link_property, self.get_concept_link(link_id), value, property_type)
@@ -1306,7 +1553,7 @@ class TalismanAPIAdapter:
         return link_property
 
     def get_concept_link_type_by_name(
-        self, link_name: str, from_type_id: str, to_type_id: str
+        self, link_name: str, from_type_id: str, to_type_id: str, limit: int = 20
     ) -> Sequence[ConceptLinkType]:
 
         op = Operation(Query)
@@ -1315,7 +1562,8 @@ class TalismanAPIAdapter:
                 name=link_name,
                 concept_from_type_id=from_type_id,
                 concept_to_type_id=to_type_id
-            )
+            ),
+            limit=limit
         )
         pclt.list_concept_link_type().__fields__(*self.concept_link_type_fields)
         res = self._gql_client.execute(op)
@@ -1538,3 +1786,131 @@ class TalismanAPIAdapter:
         return res.get_or_add_concept
 
     # endregion
+
+    # region tcontroller methods
+
+    def get_pipeline_configs(
+        self, with_transforms: bool = True, filter_settings: tc.PipelineConfigFilter = None,
+        limit: Optional[int] = None, offset: Optional[int] = None, sort_by: tc.PipelineConfigSort = 'id',
+        sort_direction: tc.SortDirection = 'ascending'
+    ) -> tc.PipelineConfigList:
+        op = Operation(tc.Query)
+        pcl: tc.PipelineConfigList = op.pipeline_configs(
+            filter=filter_settings,
+            limit=limit,
+            offset=offset,
+            sort_by=sort_by,
+            sort_direction=sort_direction
+        )
+        pc = pcl.pipeline_configs()
+        pc.__fields__(*self.pipeline_config_fields)
+        if with_transforms:
+            pc.transforms().__fields__('id')
+            pc.transforms().__fields__('params')
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.pipeline_configs
+
+    def get_pipeline_topics(
+        self, filter_settings: tc.KafkaTopicFilter = None,
+        limit: Optional[int] = None, offset: Optional[int] = None, sort_by: tc.KafkaTopicSort = 'topic',
+        sort_direction: tc.SortDirection = 'ascending'
+    ) -> tc.KafkaTopicList:
+        op = Operation(tc.Query)
+        ktl: tc.KafkaTopicList = op.kafka_topics(
+            filter=filter_settings,
+            limit=limit,
+            offset=offset,
+            sort_by=sort_by,
+            sort_direction=sort_direction
+        )
+        self._configure_pipeline_topic_fields(ktl.topics())
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.kafka_topics
+
+    def upsert_pipeline_topic(self, topic_id: str, config_id: str, stopped: bool) -> tc.KafkaTopic:
+        op = Operation(tc.Mutation)
+        kt: tc.KafkaTopic = op.put_kafka_topic(
+            topic=topic_id,
+            pipeline=tc.PipelineSetupInput(
+                pipeline_config=config_id
+            ),
+            stopped=stopped
+        )
+        self._configure_pipeline_topic_fields(kt)
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.put_kafka_topic
+
+    def get_failed_messages_from_topic(
+        self, topic_id: str, filter_settings: tc.MessageFilter = None, offset: Optional[int] = None,
+        limit: Optional[int] = None, sort_by: tc.MessageSort = 'timestamp',
+        sort_direction: tc.SortDirection = 'descending'
+    ) -> tc.FailedMessageList:
+        op = Operation(tc.Query)
+        fm: tc.FailedMessageList = op.failed_messages(
+            topic=topic_id,
+            filter=filter_settings,
+            offset=offset,
+            limit=limit,
+            sort_by=sort_by,
+            sort_direction=sort_direction
+        )
+        fm.messages().id()
+        fm.messages().info().error().description()
+        fm.messages().info().message()
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.failed_messages
+
+    def get_ok_messages_from_topic(
+        self, topic_id: str, filter_settings: tc.MessageFilter = None, offset: Optional[int] = None,
+        limit: Optional[int] = None, sort_by: tc.MessageSort = 'timestamp',
+        sort_direction: tc.SortDirection = 'descending'
+    ) -> tc.CompletedOkMessageList:
+        op = Operation(tc.Query)
+        om: tc.CompletedOkMessageList = op.completed_ok_messages(
+            topic=topic_id,
+            filter=filter_settings,
+            offset=offset,
+            limit=limit,
+            sort_by=sort_by,
+            sort_direction=sort_direction
+        )
+        om.messages().id()
+        om.messages().info().message()
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.completed_ok_messages
+
+    def get_active_messages_from_topic(
+        self, topic_id: str, filter_settings: tc.MessageFilter = None, offset: Optional[int] = None,
+        limit: Optional[int] = None, sort_by: tc.MessageSort = 'timestamp',
+        sort_direction: tc.SortDirection = 'descending'
+    ) -> tc.CompletedOkMessageList:
+        op = Operation(tc.Query)
+        am: tc.CompletedOkMessageList = op.active_messages(
+            topic=topic_id,
+            filter=filter_settings,
+            offset=offset,
+            limit=limit,
+            sort_by=sort_by,
+            sort_direction=sort_direction
+        )
+        am.messages().id()
+        am.messages().info().message()
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.active_messages
+
+    def retry_failed_in_topic(self, topic_id: str) -> int:
+        op = Operation(tc.Mutation)
+        op.retry_failed_in_topic(
+            topic=topic_id
+        )
+        res = self._gql_client.execute(op)
+        res = op + res
+        return res.retry_failed_in_topic
+
+    # endregion
