@@ -12,7 +12,7 @@ Boolean = sgqlc.types.Boolean
 
 class CollectionStatus(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('Canceled', 'Error', 'InProgress', 'Success', 'WithMistakes')
+    __choices__ = ('Canceled', 'Error', 'InProgress', 'Pending', 'Success', 'WithMistakes')
 
 
 class CrawlStateSorting(sgqlc.types.Enum):
@@ -51,7 +51,7 @@ ID = sgqlc.types.ID
 
 class InformationSourceLoaderActualStatus(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('Daily', 'EveryTwoDays', 'Never', 'Weekly')
+    __choices__ = ('Daily', 'EveryTwoDays', 'Never', 'TwiceADay', 'Weekly')
 
 
 class InformationSourceLoaderSorting(sgqlc.types.Enum):
@@ -72,12 +72,12 @@ class JSON(sgqlc.types.Scalar):
 
 class JobFinishedSort(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('args', 'collectionStatus', 'crawlerName', 'createdAt', 'createdBy', 'endTime', 'id', 'periodicJobId', 'projectName', 'settings', 'startTime')
+    __choices__ = ('args', 'collectionStatus', 'crawlerName', 'creator', 'endTime', 'id', 'periodicJobId', 'projectName', 'settings', 'startTime', 'systemRegistrationDate')
 
 
 class JobPendingSort(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('args', 'crawlerName', 'createdBy', 'id', 'jobPriority', 'periodicJobId', 'projectName', 'queueTime', 'settings')
+    __choices__ = ('args', 'crawlerName', 'creator', 'id', 'jobPriority', 'periodicJobId', 'projectName', 'queueTime', 'settings')
 
 
 class JobPriorityType(sgqlc.types.Enum):
@@ -87,7 +87,7 @@ class JobPriorityType(sgqlc.types.Enum):
 
 class JobRunningSort(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('args', 'crawlerName', 'createdAt', 'createdBy', 'id', 'jobPriority', 'periodicJobId', 'projectName', 'settings', 'startTime')
+    __choices__ = ('args', 'crawlerName', 'creator', 'id', 'jobPriority', 'periodicJobId', 'projectName', 'settings', 'startTime', 'systemRegistrationDate')
 
 
 class JobStatus(sgqlc.types.Enum):
@@ -116,7 +116,7 @@ class MetricSorting(sgqlc.types.Enum):
 
 class PeriodicJobSorting(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('changedAt', 'changedBy', 'crawlerId', 'crawlerName', 'createdAt', 'createdBy', 'id', 'name', 'nextScheduleTime', 'priority', 'projectId', 'projectName', 'status')
+    __choices__ = ('crawlerId', 'crawlerName', 'creator', 'id', 'lastUpdater', 'name', 'nextScheduleTime', 'priority', 'projectId', 'projectName', 'status', 'systemRegistrationDate', 'systemUpdateDate')
 
 
 class PeriodicJobStatus(sgqlc.types.Enum):
@@ -126,7 +126,7 @@ class PeriodicJobStatus(sgqlc.types.Enum):
 
 class ProjectSorting(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('changedAt', 'changedBy', 'createdAt', 'createdBy', 'description', 'id', 'name', 'title')
+    __choices__ = ('creator', 'description', 'id', 'lastUpdater', 'name', 'systemRegistrationDate', 'systemUpdateDate', 'title')
 
 
 class RequestSorting(sgqlc.types.Enum):
@@ -161,7 +161,7 @@ class Upload(sgqlc.types.Scalar):
 
 class VersionSorting(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
-    __choices__ = ('createdAt', 'id', 'versionName')
+    __choices__ = ('id', 'systemRegistrationDate', 'versionName')
 
 
 class VersionStatus(sgqlc.types.Enum):
@@ -207,15 +207,15 @@ class CrawlStateParameters(sgqlc.types.Input):
 
 class CrawlerFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'projects', 'crawlers_types', 'last_collection_date', 'created_by', 'changed_by', 'created_at', 'changed_at', 'have_active_versions')
+    __field_names__ = ('input_value', 'projects', 'crawlers_types', 'last_collection_date', 'creators', 'updaters', 'system_registration_date', 'system_update_date', 'have_active_versions')
     input_value = sgqlc.types.Field(String, graphql_name='inputValue')
     projects = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='projects')
     crawlers_types = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(CrawlersType)), graphql_name='crawlersTypes')
     last_collection_date = sgqlc.types.Field('TimestampInterval', graphql_name='lastCollectionDate')
-    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
-    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
-    created_at = sgqlc.types.Field('TimestampInterval', graphql_name='createdAt')
-    changed_at = sgqlc.types.Field('TimestampInterval', graphql_name='changedAt')
+    creators = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='creators')
+    updaters = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='updaters')
+    system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
+    system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
     have_active_versions = sgqlc.types.Field(Boolean, graphql_name='haveActiveVersions')
 
 
@@ -231,15 +231,15 @@ class CrawlerUpdateInput(sgqlc.types.Input):
 
 class CredentialFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'projects', 'status', 'data_type', 'created_by', 'changed_by', 'created_at', 'changed_at')
+    __field_names__ = ('input_value', 'projects', 'status', 'data_type', 'creators', 'updaters', 'system_registration_date', 'system_update_date')
     input_value = sgqlc.types.Field(String, graphql_name='inputValue')
     projects = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='projects')
     status = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(CredentialStatus)), graphql_name='status')
     data_type = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(CredentialType)), graphql_name='dataType')
-    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
-    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
-    created_at = sgqlc.types.Field('TimestampInterval', graphql_name='createdAt')
-    changed_at = sgqlc.types.Field('TimestampInterval', graphql_name='changedAt')
+    creators = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='creators')
+    updaters = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='updaters')
+    system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
+    system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
 
 
 class CredentialInput(sgqlc.types.Input):
@@ -272,14 +272,14 @@ class InformationSourceFilterSettings(sgqlc.types.Input):
 
 class InformationSourceLoaderFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'type_of_crawl', 'status', 'created_by', 'changed_by', 'created_at', 'changed_at')
+    __field_names__ = ('input_value', 'type_of_crawl', 'status', 'creators', 'updaters', 'system_registration_date', 'system_update_date')
     input_value = sgqlc.types.Field(String, graphql_name='inputValue')
     type_of_crawl = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(TypeOfCrawl)), graphql_name='typeOfCrawl')
     status = sgqlc.types.Field(CollectionStatus, graphql_name='status')
-    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
-    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
-    created_at = sgqlc.types.Field('TimestampInterval', graphql_name='createdAt')
-    changed_at = sgqlc.types.Field('TimestampInterval', graphql_name='changedAt')
+    creators = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='creators')
+    updaters = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='updaters')
+    system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
+    system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
 
 
 class InformationSourceLoaderInput(sgqlc.types.Input):
@@ -313,14 +313,14 @@ class JobSorting(sgqlc.types.Input):
 
 class JobsFilter(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'projects', 'crawlers', 'created_by', 'changed_by', 'created_at', 'changed_at', 'periodic_jobs', 'collection_statuses', 'job_ids', 'start_time', 'end_time')
+    __field_names__ = ('input_value', 'projects', 'crawlers', 'creators', 'updaters', 'system_registration_date', 'system_update_date', 'periodic_jobs', 'collection_statuses', 'job_ids', 'start_time', 'end_time')
     input_value = sgqlc.types.Field(String, graphql_name='inputValue')
     projects = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='projects')
     crawlers = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='crawlers')
-    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
-    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
-    created_at = sgqlc.types.Field('TimestampInterval', graphql_name='createdAt')
-    changed_at = sgqlc.types.Field('TimestampInterval', graphql_name='changedAt')
+    creators = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='creators')
+    updaters = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='updaters')
+    system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
+    system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
     periodic_jobs = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='periodicJobs')
     collection_statuses = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(CollectionStatus)), graphql_name='collectionStatuses')
     job_ids = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(Long)), graphql_name='jobIds')
@@ -380,16 +380,16 @@ class MetricFilterSettings(sgqlc.types.Input):
 
 class PeriodicJobFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'projects', 'crawlers', 'priorities', 'running_statuses', 'created_by', 'changed_by', 'created_at', 'changed_at', 'next_schedule_time')
+    __field_names__ = ('input_value', 'projects', 'crawlers', 'priorities', 'running_statuses', 'creators', 'updaters', 'system_registration_date', 'system_update_date', 'next_schedule_time')
     input_value = sgqlc.types.Field(String, graphql_name='inputValue')
     projects = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='projects')
     crawlers = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='crawlers')
     priorities = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(JobPriorityType)), graphql_name='priorities')
     running_statuses = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(PeriodicJobStatus)), graphql_name='runningStatuses')
-    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
-    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
-    created_at = sgqlc.types.Field('TimestampInterval', graphql_name='createdAt')
-    changed_at = sgqlc.types.Field('TimestampInterval', graphql_name='changedAt')
+    creators = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='creators')
+    updaters = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='updaters')
+    system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
+    system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
     next_schedule_time = sgqlc.types.Field('TimestampInterval', graphql_name='nextScheduleTime')
 
 
@@ -411,24 +411,22 @@ class PeriodicJobInput(sgqlc.types.Input):
 
 class ProjectFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'name', 'created_by', 'changed_by', 'created_at', 'changed_at')
+    __field_names__ = ('input_value', 'name', 'creators', 'updaters', 'system_registration_date', 'system_update_date')
     input_value = sgqlc.types.Field(String, graphql_name='inputValue')
     name = sgqlc.types.Field(String, graphql_name='name')
-    created_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='createdBy')
-    changed_by = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='changedBy')
-    created_at = sgqlc.types.Field('TimestampInterval', graphql_name='createdAt')
-    changed_at = sgqlc.types.Field('TimestampInterval', graphql_name='changedAt')
+    creators = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='creators')
+    updaters = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='updaters')
+    system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
+    system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
 
 
 class ProjectInput(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('title', 'name', 'description', 'eggfile', 'pipfile', 'lockfile', 'settings', 'args')
+    __field_names__ = ('title', 'name', 'description', 'eggfile', 'settings', 'args')
     title = sgqlc.types.Field(String, graphql_name='title')
     name = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='name')
     description = sgqlc.types.Field(String, graphql_name='description')
     eggfile = sgqlc.types.Field(String, graphql_name='eggfile')
-    pipfile = sgqlc.types.Field(String, graphql_name='pipfile')
-    lockfile = sgqlc.types.Field(String, graphql_name='lockfile')
     settings = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValueInputType))), graphql_name='settings')
     args = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValueInputType))), graphql_name='args')
 
@@ -658,7 +656,7 @@ class Metric(sgqlc.types.Type):
 
 class Mutation(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('update_crawler', 'update_crawler_settings_arguments', 'delete_crawler_versions', 'delete_crawlers', 'update_site_map_crawler_body', 'add_crawl_state', 'update_crawl_state', 'delete_crawl_state', 'add_credential', 'update_credential', 'delete_credential', 'single_upload', 'add_job', 'delete_job', 'cancel_job', 'add_periodic_job', 'run_periodic_jobs', 'update_enable_jobs_scheduling', 'update_disable_jobs_scheduling', 'delete_periodic_job', 'update_periodic_job', 'update_periodic_job_settings_and_arguments', 'delete_project', 'delete_project_versions', 'add_project', 'update_project', 'update_set_active_project', 'update_remove_active_project', 'update_project_settings_and_arguments', 'add_information_source_loader', 'delete_information_source_loader')
+    __field_names__ = ('update_crawler', 'update_crawler_settings_arguments', 'delete_crawler_versions', 'delete_crawlers', 'update_site_map_crawler_body', 'add_crawl_state', 'update_crawl_state', 'delete_crawl_state', 'add_credential', 'update_credential', 'delete_credential', 'single_upload', 'add_job', 'delete_job', 'cancel_job', 'download_pending_jobs', 'schedule_uploaded_jobs', 'add_periodic_job', 'run_periodic_jobs', 'update_enable_jobs_scheduling', 'update_disable_jobs_scheduling', 'delete_periodic_job', 'update_periodic_job', 'update_periodic_job_settings_and_arguments', 'delete_project', 'delete_project_versions', 'add_project', 'update_project', 'update_set_active_project', 'update_remove_active_project', 'update_project_settings_and_arguments', 'add_information_source_loader', 'delete_information_source_loader')
     update_crawler = sgqlc.types.Field(sgqlc.types.non_null('Crawler'), graphql_name='updateCrawler', args=sgqlc.types.ArgDict((
         ('crawler_update_input', sgqlc.types.Arg(sgqlc.types.non_null(CrawlerUpdateInput), graphql_name='crawlerUpdateInput', default=None)),
         ('crawler_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlerId', default=None)),
@@ -727,6 +725,11 @@ class Mutation(sgqlc.types.Type):
     )
     cancel_job = sgqlc.types.Field(sgqlc.types.non_null('State'), graphql_name='cancelJob', args=sgqlc.types.ArgDict((
         ('ids', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='ids', default=None)),
+))
+    )
+    download_pending_jobs = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='downloadPendingJobs')
+    schedule_uploaded_jobs = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('Job'))), graphql_name='scheduleUploadedJobs', args=sgqlc.types.ArgDict((
+        ('file_uuid', sgqlc.types.Arg(sgqlc.types.non_null(String), graphql_name='fileUUID', default=None)),
 ))
     )
     add_periodic_job = sgqlc.types.Field(sgqlc.types.non_null('PeriodicJob'), graphql_name='addPeriodicJob', args=sgqlc.types.ArgDict((
